summaryrefslogtreecommitdiffstats
path: root/kdecore/kglobalaccel.h
diff options
context:
space:
mode:
Diffstat (limited to 'kdecore/kglobalaccel.h')
-rw-r--r--kdecore/kglobalaccel.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kdecore/kglobalaccel.h b/kdecore/kglobalaccel.h
index 33dd5e37b..5e1ddd456 100644
--- a/kdecore/kglobalaccel.h
+++ b/kdecore/kglobalaccel.h
@@ -42,15 +42,15 @@ class KGlobalAccelPrivate;
* @see KKeyDialog
* @short Configurable global shortcut support
*/
-class KDECORE_EXPORT KGlobalAccel : public QObject
+class KDECORE_EXPORT KGlobalAccel : public TQObject
{
Q_OBJECT
public:
/**
* Creates a new KGlobalAccel object with the given pParent and
* psName.
* @param pParent the parent of the QObject
* @param psName the name of the QObject
*/
KGlobalAccel( TQObject* pParent, const char* psName = 0 );
virtual ~KGlobalAccel();
@@ -42,15 +42,15 @@ class KGlobalAccelPrivate;
* Creates a new KGlobalAccel object with the given pParent and
* psName.
- * @param pParent the parent of the QObject
- * @param psName the name of the QObject
+ * @param pParent the parent of the TQObject
+ * @param psName the name of the TQObject
*/
KGlobalAccel( TQObject* pParent, const char* psName = 0 );